
Change Log
==========

v.0.8.6
-------

* improved Bluetooth scanning and device discovery (thanks to a PR from @aholzel)
* added new `pfxscan` command line utility

v.0.8.5
-------

* support for new ICD revision v.3.39
* updates to the scripts and documentation

v.0.8.4
-------

* updated command line scripts to use argparse
* added new GitHub test actions

v.0.8.3
-------

* updated command line scripts to install using setuptools console_scripts for better platform compatibility

v.0.8.1
-------

* bug fixes

v.0.8.0
-------

* all new support added for v.3.38 of ICD
* support for v.1.50+ firmware which conforms to v.3.38 ICD
* added command line utility scripts which are installed into the python path
* revised documentation

v.0.7.1
-------

* revised documentation
* improved BLE notifcation callbacks

v.0.7.0
-------

* added Bluetooth LE connection access with same functionality as USB
* added convenience methods to PFxBrick class to execute actions directly
* added support for running scripts on PFx Brick

v.0.6.2
-------

* fixed error reporting for file system access methods
* fixed file directory refresh to ignore empty directory entries

v.0.6.1
-------

* changed the USB write function to ensure consistent cross-platform compatibility

v.0.6.0
-------

* finished implementing missing functionality
* finished documentation
* first public announced release

v.0.5.1
-------

* Added CHANGELOG.rst to project manifest

v.0.5.0
-------

* Initial release
